@@ -7,7 +7,7 @@ options(digits = 5)
 
 ## 1)
 
-x1 <-  fracdiff.sim( 5000, ar = .2, ma = -.4, d = .3)
+x1 <- fracdiff.sim(5000, ar = .2, ma = -.4, d = .3, n.start=0, allow.0 = TRUE)
 (fd1 <- fracdiff(x1$series, nar = 1, nma = 1, dtol = 1e-10))
 
 fdCOVcomp <-
@@ -19,7 +19,7 @@ sapply(fd1u[fdCOVcomp], signif, digits = 4)
 
 ## 2)
 
-x2 <-  fracdiff.sim( 2048, ar = .8, ma = -.4, d = .3)# -> NA's and problems
+x2 <-  fracdiff.sim( 2048, ar = .8, ma = -.4, d = .3, n.start=0, allow.0 = TRUE)# -> NA's and problems
 (fd2 <- fracdiff(x2$series, nar = length(x2$ar), nma = length(x2$ma)))
 
 fd2. <- fracdiff.var(x2$series, fd2, h = fd2$h / 2)
